<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="186"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Διαμόρφωση προσαρμοσμένης εντολής</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Προβολή</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
        <source>Use icon from theme or browse file</source>
        <translation>Χρήση εικονιδίου θέματος ή από αρχείο</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Εκτέλεση με &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
        <source>Select Font</source>
        <translation>Επιλογή γραμματοσειράς</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Text</source>
        <translation>Κείμενο</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
        <source>Command</source>
        <translation>Εντολή</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
        <source>Font</source>
        <translation>Γραμματοσειρά</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
        <source> px</source>
        <translation> εικ</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use %1 to display command output</source>
        <translation>Χρήση του %1 για την προβολή της εξόδου της εντολής</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
        <source>Icon</source>
        <translation>Εικονίδιο</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
        <source>Browse</source>
        <translation>Περιήγηση</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Αυτόματη περιστροφή όταν ο πίνακας είναι κάθετος</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
        <source>echo Configure...</source>
        <translation>Διαμόρφωση ηχώς...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Command to run</source>
        <translation>Εντολή προς εκτέλεση</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
        <source>Max Width</source>
        <translation>Μέγιστο πλάτος</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
        <source>Repeat command after:</source>
        <translation>Επανάληψη της εντολής μετά:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
        <source> second(s)</source>
        <translation> δευτερόλεπτο(α)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
        <source>Command outputs an image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
        <source>Mouse Commands</source>
        <translation>Εντολές ποντικιού</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source>Click</source>
        <translation>Κλικ</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
        <source>Wheel Up</source>
        <translation>Ρόδα προς τα πάνω</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
        <source>Wheel Down</source>
        <translation>Ρόδα προς τα κάτω</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
        <source>Select Icon File</source>
        <translation>Επιλογή του αρχείου εικονιδίου</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Εικόνες (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
